@@ -1,5 +1,5 @@
 package SimpleDB::Class::Exception;
-our $VERSION = '1.0300';
+our $VERSION = '1.0400';
 
 =head1 NAME
 
@@ -7,7 +7,7 @@ SimpleDB::Class::Exception - Exceptions thrown by SimpleDB::Class.
 
 =head1 VERSION
 
-version 1.0300
+version 1.0400
 
 =head1 DESCRIPTION
 
@@ -21,10 +21,6 @@ The following exceptions are available from this class.
 
 A general error. Isa Exception::Class.
 
-=head2 SimpleDB::Class::Exception::OverrideMe
-
-Used when creating abstract methods. Isa SimpleDB::Class::Exception.
-
 =head2 SimpleDB::Class::Exception::ObjectNotFound
 
 Thrown when a request object is not found.
@@ -49,26 +45,6 @@ Thrown when exceptions occur connecting to the SimpleDB database at Amazon, or t
 
 The HTTP status code returned.
 
-=head2 SimpleDB::Class::Exception::Response
-
-Isa SimpleDB::Class::Exception::Connection. Thrown when SimpleDB reports an error.
-
-=head3 error_code
-
-The error code returned from SimpleDB.
-
-=head3 request_id
-
-The request id as returned from SimpleDB.
-
-=head3 box_usage
-
-The storage usage in your SimpleDB.
-
-=head3 response
-
-The L<HTTP::Response> object as retrieved from the SimpleDB request.
-
 =cut
 
 use strict;
@@ -77,10 +53,6 @@ use Exception::Class (
     'SimpleDB::Class::Exception' => {
         description     => "A general error occured.",
         },
-    'SimpleDB::Class::Exception::OverrideMe' => {
-        isa             => 'SimpleDB::Class::Exception',
-        description     => 'This method should be overridden by subclasses.',
-        },
     'SimpleDB::Class::Exception::InvalidParam' => {
         isa             => 'SimpleDB::Class::Exception',
         description     => 'This method should be overridden by subclasses.',
@@ -100,11 +72,6 @@ use Exception::Class (
         description     => "There was a problem establishing a connection.",
         fields          => ['status_code'],
         },
-    'SimpleDB::Class::Exception::Response' => {
-        isa             => 'SimpleDB::Class::Exception::Connection',
-        description     => "The database reported an error.",
-        fields          => ['error_code','request_id','box_usage','response'],
-        },
 
 );
 
